@@ -2,11 +2,8 @@
 A subpackage dedicated to basic measures of the matter density field -- its 2-point structure, cosmological transfer
 functions, and filter functions which can be applied to it.
 """
-from . import transfer_models
-from . import transfer
-from . import filters
-
-from .transfer import Transfer
-from .transfer_models import CAMB, EH
+from . import filters, transfer, transfer_models
 from .filters import Filter
 from .halofit import halofit
+from .transfer import Transfer
+from .transfer_models import CAMB, EH
