@@ -91,6 +91,9 @@ class MassFunction(transfer.Transfer):
     >>> h.dndm
     """
 
+    #: Switch to turn off exceptions for mdef's not matching hmf_model
+    ERROR_ON_BAD_MDEF = True
+
     def __init__(
         self,
         Mmin: float = 10.0,
@@ -278,7 +281,7 @@ class MassFunction(transfer.Transfer):
 
             # Note we need to do the != in this order so that SOGeneric can compare.
             if self.hmf_model.get_measured_mdef() != mdef:
-                if self.disable_mass_conversion:
+                if self.disable_mass_conversion and self.ERROR_ON_BAD_MDEF:
                     raise ValueError(
                         f"Your input mass definition '{mdef}' does not match the mass "
                         f"definition in which the hmf fit {self.hmf_model.__name__} was "
@@ -286,15 +289,18 @@ class MassFunction(transfer.Transfer):
                         f"automatic mass conversion by setting `disable_mass_conversion=False, "
                         "or use the correct mass definition."
                     )
-                else:
-                    warnings.warn(
-                        f"Your input mass definition '{mdef}' does not match the mass "
-                        f"definition in which the hmf fit {self.hmf_model.__name__} was measured:"
-                        f"'{self.hmf_model.get_measured_mdef()}'. The mass function will be "
-                        f"converted to your input definition, "
-                        f"but note that some properties do not survive the conversion, eg. "
-                        f"the integral of the hmf over mass yielding the total mean density."
-                    )
+                extra_msg = (
+                    "The mass function will be "
+                    "converted to your input definition, "
+                    "but note that some properties do not survive the conversion, eg. "
+                    "the integral of the hmf over mass yielding the total mean density."
+                )
+
+                warnings.warn(
+                    f"Your input mass definition '{mdef}' does not match the mass "
+                    f"definition in which the hmf fit {self.hmf_model.__name__} was measured:"
+                    f"'{self.hmf_model.get_measured_mdef()}'. {extra_msg if not self.disable_mass_conversion else ''}"
+                )
 
         return mdef
 
@@ -454,7 +460,7 @@ class MassFunction(transfer.Transfer):
         The number density of haloes, ``len=len(m)`` [units :math:`h^4 M_\odot^{-1} Mpc^{-3}`]
         """
         # if self.z2 is None:  # #This is normally the case
-        dndm = self.fsigma * self.mean_density0 * np.abs(self._dlnsdlnm) / self.m ** 2
+        dndm = self.fsigma * self.mean_density0 * np.abs(self._dlnsdlnm) / self.m**2
         if isinstance(self.hmf, ff.Behroozi):
             ngtm_tinker = self._gtm(dndm)
             dndm = self.hmf._modify_dndm(self.m, dndm, self.z, ngtm_tinker)
@@ -511,7 +517,7 @@ class MassFunction(transfer.Transfer):
         # If the highest mass is very low, we try calculating it to higher masses
         # The dlog10m is NOT CHANGED, so the input needs to be finely spaced.
         # If the top value of dndm is NaN, don't try calculating higher masses.
-        if m[-1] < 10 ** 16.5 and not np.isnan(dndm[-1]) and not dndm[-1] == 0:
+        if m[-1] < 10**16.5 and not np.isnan(dndm[-1]) and not dndm[-1] == 0:
             # ff.Behroozi function won't work here.
             if not isinstance(self.hmf, ff.Behroozi):
                 new_mf = copy.deepcopy(self)
